@@ -52,7 +52,7 @@ static char *opcode2str(uint8_t opcode)
 	case 0x05:
 		return "SetPath";
 	case 0x06:
-		return "Reserved";
+		return "Action";
 	case 0x07:
 		return "Session";
 	case 0x7f:
@@ -181,6 +181,12 @@ static char *hi2str(uint8_t hi)
 		return "Session Parameters";
 	case 0x13:
 		return "Session Sequence Number";
+	case 0x14:
+		return "Action ID";
+	case 0x15:
+		return "DestName";
+	case 0x16:
+		return "Permission";
 	default:
 		return "Unknown";
 	}
